@@ -32,7 +32,7 @@ void IncludeFileItem::execute(View* view, const Range& _word)
     QChar closeChar;
     {
         const QString textBefore = document->text(Range(Cursor(0, 0), _word.start()));
-        QRegExp regexp("(?:include|require)(?:_once)?(\\s*)(\\(?)(\\s*)(?:dirname\\s*\\(\\s*__FILE__\\s*\\)\\s*\\.\\s*)?([\"'])", Qt::CaseInsensitive);
+        QRegularExpression regexp("(?:include|require)(?:_once)?(\\s*)(\\(?)(\\s*)(?:dirname\\s*\\(\\s*__FILE__\\s*\\)\\s*\\.\\s*)?([\"'])", Qt::CaseInsensitive);
 
         if ( regexp.lastIndexIn(textBefore) != -1 ) {
             closeChar = regexp.cap(4).at(0);
