@@ -43,7 +43,7 @@ public:
     {
         beginResetModel();
         m_completionItems.clear();
-        foreach(const CompletionTreeItemPointer &i, items) {
+        for(const CompletionTreeItemPointer &i : items) {
             m_completionItems << QExplicitlySharedDataPointer<CompletionTreeElement>(i);
         }
         m_completionContext = KDevelop::CodeCompletionContext::Ptr(completionContext);
@@ -134,7 +134,7 @@ TestCompletion::TestCompletion()
 void TestCompletion::dumpCompletionItems(QList<CompletionTreeItemPointer> items)
 {
     qDebug() << items.count() << "completion items:";
-    foreach(const CompletionTreeItemPointer &item, items) {
+    for(const CompletionTreeItemPointer &item : items) {
         qDebug() << item->declaration()->toString();
     }
 }
@@ -276,7 +276,7 @@ void TestCompletion::methodCall()
 
         QString ret;
         createArgumentList(*item2, ret, 0);
-        QCOMPARE(ret, QString("(A $a, null $b = null)"));
+        QCOMPARE(ret, QStringLiteral("(A $a, null $b = null)"));
     }
     {
         PhpCompletionTester tester(top, QStringLiteral("blah; $i->foo(new A(), "));
@@ -518,7 +518,7 @@ void TestCompletion::nameNormalVariable()
     PhpCompletionTester tester(top, {});
     QCOMPARE(tester.completionContext->memberAccessOperation(), CodeCompletionContext::NoMemberAccess);
 
-    foreach(const QString &id, QStringList() << "ghi" << "def" << "$abc" << "$arr") {
+    for(const QString &id :  QStringList() << "ghi" << "def" << "$abc" << "$arr") {
         QVERIFY(tester.names.contains(id, Qt::CaseSensitive));
     }
 }
@@ -543,7 +543,7 @@ void TestCompletion::nameClassMember()
     CompletionTreeItemPointer itm = searchDeclaration(tester.items, top->childContexts().first()->localDeclarations().first());
     QVERIFY(itm);
     QCOMPARE(itm->data(model->index(0, Php::CodeCompletionModel::Name), Qt::DisplayRole, model).toString(),
-             QString("abc"));
+             QStringLiteral("abc"));
 
     //don't delete model as its constructor does bad things (quit the current thread - we don't want that in test)
     //TODO find better solution that doesn't leak
@@ -806,7 +806,7 @@ void TestCompletion::verifyExtendsOrImplements(const QString &codeStr, const QSt
     QVERIFY(!tester.items.isEmpty());
     // make sure the items are unique
     QCOMPARE(tester.names.size(), tester.names.toSet().size());
-    foreach(const CompletionTreeItemPointer &item, tester.items) {
+    for(const CompletionTreeItemPointer &item : tester.items) {
         ClassDeclaration* klass = dynamic_cast<ClassDeclaration*>(item->declaration().data());
         QVERIFY(klass);
         QVERIFY(klass->classModifier() != ClassDeclarationData::Final);
@@ -920,7 +920,7 @@ void TestCompletion::unsureType()
     QCOMPARE(tester.completionContext->memberAccessOperation(), CodeCompletionContext::MemberAccess);
 
     qDebug() << tester.names;
-    foreach(const QString &id, QStringList() << "vA" << "vB") {
+    for(const QString &id : QStringList() << "vA" << "vB") {
         QVERIFY(tester.names.contains(id, Qt::CaseSensitive));
     }
 }
@@ -931,7 +931,7 @@ void TestCompletion::completionAfterComments()
     DUChainReleaser releaseTop(top);
     DUChainWriteLocker lock(DUChain::lock());
 
-    foreach ( const QString &code, QStringList() << "# asdf\n"
+    for( const QString &code : QStringList() << "# asdf\n"
                                     << "// asdf\n"
                                     << "/* */" )
     {
@@ -951,7 +951,7 @@ void TestCompletion::completionInComments()
     DUChainReleaser releaseTop(top);
     DUChainWriteLocker lock(DUChain::lock());
 
-    foreach ( const QString &code, QStringList() << "# "
+    for( const QString &code : QStringList() << "# "
                                     << "// " << "/* " )
     {
         PhpCompletionTester tester(top, code);
@@ -966,7 +966,7 @@ void TestCompletion::phpStartTag()
     DUChainReleaser releaseTop(top);
     DUChainWriteLocker lock(DUChain::lock());
 
-    foreach ( const QString &code, QStringList() << "p" << "ph" << "php" ) {
+    for( const QString &code : QStringList() << "p" << "ph" << "php" ) {
         PhpCompletionTester tester(top, QStringLiteral("<?"), code);
 
         QVERIFY(tester.items.isEmpty());
@@ -1009,7 +1009,7 @@ void TestCompletion::fileCompletion()
 
     ///TODO: somehow offer files and check whether they work with relative sub-paths
     ///TODO: make sure items after dirname(__FILE__) or similar start with a /
-    foreach ( const QString& code, QStringList() << "include \"" << "include_once \"" << "require_once \""
+    for( const QString& code : QStringList() << "include \"" << "include_once \"" << "require_once \""
                                                  << "require \"" << "include ( \""
                                                  << "include dirname(__FILE__) . \"/"
                                                  << "include ( dirname(__FILE__) . \"/"
@@ -1031,7 +1031,7 @@ void TestCompletion::instanceof()
 
     PhpCompletionTester tester(top, QStringLiteral("$a instanceof "));
 
-    foreach ( const QString& name, QStringList() << "a" << "b" << "c" << "d" ) {
+    for( const QString& name : QStringList() << "a" << "b" << "c" << "d" ) {
         qDebug() << name;
         QList<Declaration*> decs = top->findLocalDeclarations(Identifier(name));
         QCOMPARE(decs.size(), 1);
@@ -1040,7 +1040,7 @@ void TestCompletion::instanceof()
         QVERIFY(searchDeclaration(tester.items, cdec));
     }
 
-    foreach ( const CompletionTreeItemPointer &item, tester.items ) {
+    for( const CompletionTreeItemPointer &item : tester.items ) {
         QVERIFY(dynamic_cast<ClassDeclaration*>(item->declaration().data()));
     }
 }
@@ -1051,11 +1051,11 @@ void TestCompletion::afterFunctionArg()
     DUChainReleaser releaseTop(top);
     DUChainWriteLocker lock(DUChain::lock());
 
-    foreach ( const QString &code, QStringList() << "if ($a->" << "while ($a->" << "foobar($a->" ) {
+    for( const QString &code : QStringList() << "if ($a->" << "while ($a->" << "foobar($a->" ) {
         qDebug() << code;
         PhpCompletionTester tester(top, code);
         QCOMPARE(tester.names.size(), 1);
-        QCOMPARE(tester.names.first(), QString("b"));
+        QCOMPARE(tester.names.first(), QStringLiteral("b"));
     }
 }
 
@@ -1135,7 +1135,7 @@ void TestCompletion::functionArguments()
     PhpCompletionTester tester(top->childContexts().last(), {});
     // should get two local and the func itself
     QVERIFY(searchDeclaration(tester.items, fDec));
-    foreach( Declaration* dec, args ) {
+    for( Declaration* dec : args ) {
         qDebug() << dec->toString();
         QVERIFY(searchDeclaration(tester.items, dec));
     }
@@ -1196,7 +1196,7 @@ void TestCompletion::ctorCall()
 
         QString ret;
         createArgumentList(*item2, ret, 0);
-        QCOMPARE(ret, QString("(string $bar)"));
+        QCOMPARE(ret, QStringLiteral("(string $bar)"));
     }
     {
         PhpCompletionTester tester(top, QStringLiteral("new B("));
@@ -1211,7 +1211,7 @@ void TestCompletion::ctorCall()
 
         QString ret;
         createArgumentList(*item2, ret, 0);
-        QCOMPARE(ret, QString("(bool $asdf)"));
+        QCOMPARE(ret, QStringLiteral("(bool $asdf)"));
     }
 }
 
@@ -1251,7 +1251,7 @@ void TestCompletion::funcCallInConditional()
 
         QString ret;
         createArgumentList(*item2, ret, 0);
-        QCOMPARE(ret, QString("(mixed $a, int $b = 1)"));
+        QCOMPARE(ret, QStringLiteral("(mixed $a, int $b = 1)"));
     }
 }
 
