@@ -22,13 +22,13 @@ class PhpUnitRunJob : public KJob
 {
     Q_OBJECT
 public:
-    PhpUnitRunJob(PhpUnitTestSuite* suite, const QStringList& cases, KDevelop::OutputJob::OutputJobVerbosity verbosity, QObject* parent = 0);
+    PhpUnitRunJob(PhpUnitTestSuite* suite, const QStringList& cases, KDevelop::OutputJob::OutputJobVerbosity verbosity, QObject* parent = nullptr);
     virtual void start();
 
 protected:
     virtual bool doKill();
 
-private slots:
+private Q_SLOTS:
     void processFinished(KJob* job);
     void rowsInserted(const QModelIndex &parent, int startRow, int endRow);
 
