@@ -97,7 +97,7 @@ bool CodeGenObjectWithTextBlocks::removeTextBlock (TextBlock * remove_object)
     }
     else {
         // may be hiding in child hierarchical codeblock
-        foreach (TextBlock* tb, m_textblockVector) {
+        for (TextBlock* tb: m_textblockVector) {
             HierarchicalCodeBlock * hb = dynamic_cast<HierarchicalCodeBlock*>(tb);
             if (hb && hb->removeTextBlock(remove_object))
                 return true;
@@ -124,7 +124,7 @@ TextBlock * CodeGenObjectWithTextBlocks::findTextBlockByTag(const QString &tag)
     if (m_textBlockTagMap.contains(tag)) {
         return m_textBlockTagMap[tag];
     }
-    return 0;
+    return nullptr;
 }
 
 /**
@@ -146,7 +146,7 @@ CodeGenObjectWithTextBlocks * CodeGenObjectWithTextBlocks::findParentObjectForTa
 
     if (!findTextBlockByTag(tag)) {
         // may be hiding in child hierarchical codeblock
-        foreach (TextBlock* tb, m_textblockVector) {
+        for (TextBlock* tb: m_textblockVector) {
             HierarchicalCodeBlock * hb = dynamic_cast<HierarchicalCodeBlock*>(tb);
             if (hb) {
                 CodeGenObjectWithTextBlocks* cgowtb = dynamic_cast<CodeGenObjectWithTextBlocks*>(hb);
@@ -248,7 +248,7 @@ CodeComment * CodeGenObjectWithTextBlocks::addOrUpdateTaggedCodeComment (const Q
         codeComment->setTag(tag);
         if (!addTextBlock(codeComment)) {
             delete codeComment;
-            return 0; // hmm. total failure.., was there a preexisting comment with this tag?? lets return null
+            return nullptr; // hmm. total failure.., was there a preexisting comment with this tag?? lets return null
         }
     }
 
@@ -288,7 +288,7 @@ CodeBlockWithComments * CodeGenObjectWithTextBlocks::addOrUpdateTaggedCodeBlockW
         codeBlock->setTag(tag);
         if (!addTextBlock(codeBlock)) {
             delete codeBlock;
-            return 0; // hmm. total failure.., was there a preexisting codeblock with this tag?? lets return null
+            return nullptr; // hmm. total failure.., was there a preexisting codeblock with this tag?? lets return null
         }
     }
 
@@ -340,7 +340,7 @@ void CodeGenObjectWithTextBlocks::setAttributesFromObject (CodeGenObjectWithText
     Q_UNUSED(obj);
 /*
     TextBlockList * list = obj->getTextBlockList();
-    foreach (TextBlock* tb, *list) {
+    for (TextBlock* tb :  *list) {
         // FIX : we need some functionality like
         // loadChildTextBlocksFromObject(obj) here
     }
@@ -358,7 +358,7 @@ void CodeGenObjectWithTextBlocks::setAttributesOnNode (QXmlStreamWriter& writer)
 
     // only concrete calls to textblocks are saved
     TextBlockList * tbList = getTextBlockList();
-    foreach (TextBlock* block, *tbList) {
+    for (TextBlock* block: *tbList) {
         block->saveToXMI(writer);
     }
     writer.writeEndElement();
