@@ -1,8 +1,8 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
 
-    SPDX-FileCopyrightText: 2003-2020 Oliver Kellogg <okellogg@users.sourceforge.net>
-    SPDX-FileCopyrightText: 2003-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2003-2021 Oliver Kellogg <okellogg@users.sourceforge.net>
+    SPDX-FileCopyrightText: 2003-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #ifndef IDLWRITER_H
@@ -32,7 +32,7 @@ public:
 
     virtual Uml::ProgrammingLanguage::Enum language() const;
 
-    QStringList defaultDatatypes();
+    QStringList defaultDatatypes() const;
 
     virtual QStringList reservedKeywords() const;
 
