@@ -2,7 +2,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 
     SPDX-FileCopyrightText: 2003 Brian Thomas <thomas@mail630.gsfc.nasa.gov>
-    SPDX-FileCopyrightText: 2004-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2004-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -47,7 +47,7 @@ QString JavaCodeClassField::getFieldName()
         if(fieldIsSingleValue()) {
             return roleName.replace(0, 1, roleName.left(1).toLower());
         } else {
-            return roleName.toLower() + QLatin1String("Vector");
+            return roleName.toLower() + QStringLiteral("Vector");
         }
     }
 }
@@ -56,11 +56,11 @@ QString JavaCodeClassField::getInitialValue()
 {
     if (parentIsAttribute())
     {
-        UMLAttribute * at = getParentObject()->asUMLAttribute();
+        const UMLAttribute * at = getParentObject()->asUMLAttribute();
         if (at) {
             return fixInitialStringDeclValue(at->getInitialValue(), getTypeName());
         } else {
-            uError() << "parent object is not a UMLAttribute";
+            logError0("JavaCodeClassField::getInitialValue: parent object is not a UMLAttribute");
             return QString();
         }
     }
@@ -71,7 +71,7 @@ QString JavaCodeClassField::getInitialValue()
             //       then we can just return 'empty' string (minor problem).
             return QString();
         } else {
-            return QLatin1String(" new ") + JavaCodeGenerator::getListFieldClassName() + QLatin1String("()");
+            return QStringLiteral(" new ") + JavaCodeGenerator::getListFieldClassName() + QStringLiteral("()");
         }
     }
 }
