@@ -22,7 +22,7 @@
 
 // qt includes
 #include <QFile>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QTextStream>
 
 /**
@@ -68,14 +68,14 @@ void JavaWriter::writeClass(UMLClassifier *c)
     //find an appropriate name for our file
     fileName = findFileName(c, QStringLiteral(".java"));
     if (fileName.isEmpty()) {
-        emit codeGenerated(c, false);
+        Q_EMIT codeGenerated(c, false);
         return;
     }
 
     // check that we may open that file for writing
     QFile file;
     if (!openFile(file, fileName)) {
-        emit codeGenerated(c, false);
+        Q_EMIT codeGenerated(c, false);
         return;
     }
 
@@ -89,7 +89,7 @@ void JavaWriter::writeClass(UMLClassifier *c)
 
     if (!m_isInterface) {
         UMLAttributeList atl = c->getAttributeList();
-        foreach (UMLAttribute *at,  atl) {
+        for (UMLAttribute *at :   atl) {
             switch(at->visibility())
             {
               case Uml::Visibility::Public:
@@ -139,8 +139,8 @@ void JavaWriter::writeClass(UMLClassifier *c)
     QString str;
     str = getHeadingFile(QStringLiteral(".java"));
     if (!str.isEmpty()) {
-        str.replace(QRegExp(QStringLiteral("%filename%")), fileName);
-        str.replace(QRegExp(QStringLiteral("%filepath%")), file.fileName());
+        str.replace(QRegularExpression(QStringLiteral("%filename%")), fileName);
+        str.replace(QRegularExpression(QStringLiteral("%filepath%")), file.fileName());
         java << str << m_endl;
     }
 
@@ -160,7 +160,7 @@ void JavaWriter::writeClass(UMLClassifier *c)
     //only import classes in a different package as this class
     UMLPackageList imports;
     findObjectsRelated(c, imports);
-    foreach (UMLPackage* con,  imports) {
+    for (UMLPackage* con :   imports) {
         if (con->isUMLDatatype())
             continue;
         QString pkg = con->package();
@@ -258,7 +258,7 @@ void JavaWriter::writeClass(UMLClassifier *c)
     java << "}" << m_endl; // end class
 
     file.close();
-    emit codeGenerated(c, true);
+    Q_EMIT codeGenerated(c, true);
 }
 
 /**
@@ -323,7 +323,7 @@ void JavaWriter::writeClassDecl(UMLClassifier *c, QTextStream &java)
     UMLClassifierList superclasses = c->findSuperClassConcepts(UMLClassifier::CLASS);
 
     int i = 0;
-    foreach (UMLClassifier *classifier, superclasses) {
+    for (UMLClassifier *classifier :  superclasses) {
         if (i == 0)
         {
             java <<  " extends ";
@@ -339,7 +339,7 @@ void JavaWriter::writeClassDecl(UMLClassifier *c, QTextStream &java)
 
     UMLClassifierList superInterfaces = c->findSuperClassConcepts(UMLClassifier::INTERFACE);
     i = 0;
-    foreach (UMLClassifier *classifier, superInterfaces) {
+    for (UMLClassifier *classifier :  superInterfaces) {
         if (i == 0)
         {
             if (m_isInterface)
@@ -368,7 +368,7 @@ void JavaWriter::writeClassDecl(UMLClassifier *c, QTextStream &java)
 void JavaWriter::writeAttributeDecls(UMLAttributeList &atpub, UMLAttributeList &atprot,
                                      UMLAttributeList &atpriv, QTextStream &java)
 {
-    foreach (UMLAttribute *at, atpub) {
+    for (UMLAttribute *at :  atpub) {
         QString documentation = at->doc();
         QString staticValue = at->isStatic() ? QStringLiteral("static ") : QString();
         QString typeName = fixTypeName(at->getTypeName());
@@ -379,7 +379,7 @@ void JavaWriter::writeAttributeDecls(UMLAttributeList &atpub, UMLAttributeList &
              << (initialValue.isEmpty() ? QString() : QStringLiteral(" = ") + initialValue) << ";";
     }
 
-    foreach (UMLAttribute *at, atprot){
+    for (UMLAttribute *at :  atprot){
         QString documentation = at->doc();
         QString typeName = fixTypeName(at->getTypeName());
         QString staticValue = at->isStatic() ? QStringLiteral("static ") : QString();
@@ -390,7 +390,7 @@ void JavaWriter::writeAttributeDecls(UMLAttributeList &atpub, UMLAttributeList &
              << (initialValue.isEmpty() ? QString() : QStringLiteral(" = ") + initialValue) << ";";
     }
 
-    foreach (UMLAttribute *at, atpriv) {
+    for (UMLAttribute *at :  atpriv) {
         QString documentation = at->doc();
         QString typeName = fixTypeName(at->getTypeName());
         QString staticValue = at->isStatic() ? QStringLiteral("static ") : QString();
@@ -408,7 +408,7 @@ void JavaWriter::writeAttributeDecls(UMLAttributeList &atpub, UMLAttributeList &
  */
 void JavaWriter::writeAttributeMethods(UMLAttributeList &atpub, Uml::Visibility::Enum visibility, QTextStream &java)
 {
-    foreach (UMLAttribute *at, atpub){
+    for (UMLAttribute *at :  atpub){
         QString fieldName = cleanName(at->name());
         // force capitalizing the field name, this is silly,
         // from what I can tell, this IS the default behavior for
@@ -432,7 +432,7 @@ void JavaWriter::writeComment(const QString &comment, const QString &myIndent,
     // in the case we have several line comment..
     // NOTE: this part of the method has the problem of adopting UNIX newline,
     // need to resolve for using with MAC/WinDoze eventually I assume
-    if (comment.contains(QRegExp(QStringLiteral("\n")))) {
+    if (comment.contains(QRegularExpression(QStringLiteral("\n")))) {
 
         if (javaDocStyle)
             java << myIndent << "/**" << m_endl;
@@ -491,7 +491,7 @@ void JavaWriter::writeAssociationDecls(UMLAssociationList associations, Uml::ID:
     if (forceSections() || !associations.isEmpty())
     {
         bool printRoleA = false, printRoleB = false;
-        foreach (UMLAssociation *a, associations) {
+        for (UMLAssociation *a :  associations) {
             // it may seem counter intuitive, but you want to insert the role of the
             // *other* class into *this* class.
             if (a->getObjectId(Uml::RoleType::A) == id)
@@ -544,7 +544,7 @@ void JavaWriter::writeAssociationRoleDecl(QString fieldClassName,
     // declare the association based on whether it is this a single variable
     // or a List (Vector). One day this will be done correctly with special
     // multiplicity object that we don't have to figure out what it means via regex.
-    if (multi.isEmpty() || multi.contains(QRegExp(QStringLiteral("^[01]$"))))
+    if (multi.isEmpty() || multi.contains(QRegularExpression(QStringLiteral("^[01]$"))))
     {
         QString fieldVarName = QStringLiteral("m_") + roleName.replace(0, 1, roleName.left(1).toLower());
         java << m_startline << scope << " " << fieldClassName << " " << fieldVarName << ";";
@@ -566,7 +566,7 @@ void JavaWriter::writeAssociationMethods (UMLAssociationList associations, UMLCl
 {
     if (forceSections() || !associations.isEmpty()) {
 
-        foreach(UMLAssociation *a, associations) {
+        for (UMLAssociation *a :  associations) {
 
             // insert the methods to access the role of the other
             // class in the code of this one
@@ -610,7 +610,7 @@ void JavaWriter::writeAssociationRoleMethod (QString fieldClassName, QString rol
         QString description, Uml::Visibility::Enum visib, Uml::Changeability::Enum change,
         QTextStream &java)
 {
-    if (multi.isEmpty() || multi.contains(QRegExp(QStringLiteral("^[01]$"))))
+    if (multi.isEmpty() || multi.contains(QRegularExpression(QStringLiteral("^[01]$"))))
     {
         QString fieldVarName = QStringLiteral("m_") + roleName.replace(0, 1, roleName.left(1).toLower());
         writeSingleAttributeAccessorMethods(fieldClassName, fieldVarName, roleName,
@@ -764,7 +764,7 @@ QStringList JavaWriter::defaultDatatypes() const
  */
 bool JavaWriter::compareJavaMethod(UMLOperation *op1, UMLOperation *op2)
 {
-    if (op1 == 0 || op2 == 0)
+    if (op1 == nullptr || op2 == nullptr)
         return false;
     if (op1 == op2)
         return true;
@@ -791,7 +791,7 @@ bool JavaWriter::compareJavaMethod(UMLOperation *op1, UMLOperation *op2)
  */
 bool JavaWriter::javaMethodInList(UMLOperation *umlOp, UMLOperationList &opl)
 {
-    foreach (UMLOperation *op, opl) {
+    for (UMLOperation *op :  opl) {
         if (JavaWriter::compareJavaMethod(op, umlOp)) {
             return true;
         }
@@ -811,11 +811,11 @@ void JavaWriter::getSuperImplementedOperations(UMLClassifier *c, UMLOperationLis
 {
     UMLClassifierList superClasses = c->findSuperClassConcepts();
 
-    foreach (UMLClassifier *classifier, superClasses) {
+    for (UMLClassifier *classifier :  superClasses) {
 
         getSuperImplementedOperations(classifier, yetImplementedOpList, toBeImplementedOpList, (classifier->isInterface() && noClassInPath));
         UMLOperationList opl = classifier->getOpList();
-        foreach (UMLOperation *op, opl) {
+        for (UMLOperation *op :  opl) {
             if (classifier->isInterface() && noClassInPath) {
                 if (!JavaWriter::javaMethodInList(op, toBeImplementedOpList))
                     toBeImplementedOpList.append(op);
@@ -841,7 +841,7 @@ void JavaWriter::getInterfacesOperationsToBeImplemented(UMLClassifier *c, UMLOpe
     UMLOperationList toBeImplementedOpList;
 
     getSuperImplementedOperations(c, yetImplementedOpList, toBeImplementedOpList);
-    foreach (UMLOperation *op, toBeImplementedOpList) {
+    for (UMLOperation *op :  toBeImplementedOpList) {
         if (! JavaWriter::javaMethodInList(op, yetImplementedOpList) && ! JavaWriter::javaMethodInList(op, opList))
             opList.append(op);
     }
@@ -861,7 +861,7 @@ void JavaWriter::writeOperations(UMLClassifier *c, QTextStream &java) {
     if (! c->isInterface()) {
         getInterfacesOperationsToBeImplemented(c, opl);
     }
-    foreach (UMLOperation *op, opl) {
+    for (UMLOperation *op :  opl) {
         switch(op->visibility()) {
           case Uml::Visibility::Public:
             oppub.append(op);
@@ -919,7 +919,7 @@ void JavaWriter::writeOperations(UMLOperationList &oplist, QTextStream &java)
     QString str;
 
     // generate method decl for each operation given
-    foreach (UMLOperation* op, oplist) {
+    for (UMLOperation* op :  oplist) {
 
         QString doc;
         // write documentation
@@ -937,7 +937,7 @@ void JavaWriter::writeOperations(UMLOperationList &oplist, QTextStream &java)
         atl = op->getParmList();
         i= atl.count();
         j=0;
-        foreach (UMLAttribute* at, atl) {
+        for (UMLAttribute* at :  atl) {
             QString typeName = fixTypeName(at->getTypeName());
             QString atName = cleanName(at->name());
             str += typeName + QLatin1Char(' ') + atName +
@@ -947,7 +947,7 @@ void JavaWriter::writeOperations(UMLOperationList &oplist, QTextStream &java)
             doc += QStringLiteral("@param        ") + atName + QLatin1Char(' ') + at->doc() + QLatin1Char('\n');
             j++;
         }
-        doc = doc.remove(doc.size() - 1, 1);  // remove last endl of comment
+        doc = doc.remove(doc.size() - 1, 1);  // remove last '\n' of comment
         str += QLatin1Char(')');
 
         // method only gets a body IF it is not abstract
