@@ -2,7 +2,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 
     SPDX-FileCopyrightText: 2003 Brian Thomas <thomas@mail630.gsfc.nasa.gov>
-    SPDX-FileCopyrightText: 2004-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2004-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #include "xmlcodecomment.h"
@@ -26,11 +26,11 @@ QString XMLCodeComment::toString () const
         QString indent = getIndentationString();
         QString endLine = getNewLineEndingChars();
         QString body = getText();
-        output.append(indent + QLatin1String("<!-- "));
+        output.append(indent + QStringLiteral("<!-- "));
         if (!body.isEmpty()) {
             output.append(formatMultiLineText (body, indent, endLine));
         }
-        output.append(indent + QLatin1String("-->") + endLine);
+        output.append(indent + QStringLiteral("-->") + endLine);
     }
 
     return output;
