@@ -24,7 +24,7 @@
 
 // qt includes
 #include <QProcess>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QStandardPaths>
 #include <QStringList>
 
@@ -71,7 +71,7 @@ IDLImport::IDLImport(CodeImpThread* thread) : NativeImportBase(QStringLiteral("/
         m_preProcessorArguments = arguments;
     }
     else {
-        log("Error: Cannot find any of the supported preprocessors (gcc, Microsoft Visual Studio 2010)");
+        log(QStringLiteral("Error: Cannot find any of the supported preprocessors (gcc, Microsoft Visual Studio 2010)"));
         m_enabled = false;
     }
     m_preProcessorChecked = true;
@@ -140,14 +140,14 @@ bool IDLImport::parseFile(const QString& filename)
 {
     if (filename.contains(QLatin1Char('/'))) {
         QString path = filename;
-        path.remove(QRegExp(QStringLiteral("/[^/]+$")));
+        path.remove(QRegularExpression(QStringLiteral("/[^/]+$")));
         logDebug1("IDLImport::parseFile adding path %1", path);
         Import_Utils::addIncludePath(path);
     }
     const QStringList includePaths = Import_Utils::includePathList();
 
     if (m_preProcessor.isEmpty()) { 
-        log("Error: no preprocessor installed, could not import file");
+        log(QStringLiteral("Error: no preprocessor installed, could not import file"));
         return false;
     }
     QStringList arguments(m_preProcessorArguments);
@@ -162,12 +162,12 @@ bool IDLImport::parseFile(const QString& filename)
     logDebug2("importIDL::parseFile: %1 %2", m_preProcessor, arguments.join(QStringLiteral(" ")));
     p.start(m_preProcessor, arguments);
     if (!p.waitForStarted()) {
-        log("Error: could not run preprocessor");
+        log(QStringLiteral("Error: could not run preprocessor"));
         return false;
     }
 
     if (!p.waitForFinished()) {
-        log("Error: could not run preprocessor");
+        log(QStringLiteral("Error: could not run preprocessor"));
         return false;
     }
     int exitCode = p.exitCode();
@@ -188,7 +188,7 @@ bool IDLImport::parseFile(const QString& filename)
 
     // Parse the QStringList m_source.
     m_scope.clear();
-    pushScope(0); // global scope
+    pushScope(nullptr); // global scope
     const int srcLength = m_source.count();
     for (m_srcIndex = 0; m_srcIndex < srcLength; ++m_srcIndex) {
         const QString& keyword = m_source[m_srcIndex];
@@ -222,7 +222,7 @@ bool IDLImport::skipStructure()
  * Returns true if the given text is a valid IDL scoped name.
  */
 bool IDLImport::isValidScopedName(QString text) {
-    QRegExp validScopedName(QStringLiteral("^[A-Za-z_:][A-Za-z0-9_:]*$"));
+    QRegularExpression validScopedName(QStringLiteral("^[A-Za-z_:][A-Za-z0-9_:]*$"));
     return text.contains(validScopedName);
 }
 
@@ -390,11 +390,11 @@ bool IDLImport::parseStmt()
         UMLObject *ns = Import_Utils::createUMLObject(UMLObject::ot_Enum,
                         name, currentScope(), m_comment);
         UMLEnum *enumType = ns->asUMLEnum();
-        if (enumType == 0)
+        if (enumType == nullptr)
             enumType = Import_Utils::remapUMLEnum(ns, currentScope());
         m_srcIndex++;  // skip name
         while (++m_srcIndex < srcLength && m_source[m_srcIndex] != QStringLiteral("}")) {
-            if (enumType != 0)
+            if (enumType != nullptr)
                 Import_Utils::addEnumLiteral(enumType, m_source[m_srcIndex]);
             if (advance() != QStringLiteral(","))
                 break;
@@ -427,7 +427,7 @@ bool IDLImport::parseStmt()
             skipStmt();
             UMLObject::ObjectType ot = (oldType.length() ? UMLObject::ot_Class : UMLObject::ot_Datatype);
             UMLObject *pOld = m_doc->findUMLObject(oldType, UMLObject::ot_UMLObject, currentScope());
-            if (pOld == 0) {
+            if (pOld == nullptr) {
                 pOld = Import_Utils::createUMLObject(ot, oldType, currentScope());
             }
             UMLObject *dt = Import_Utils::createUMLObject(ot, newType, currentScope(), m_comment);
@@ -438,7 +438,7 @@ bool IDLImport::parseStmt()
             }
             QString stereoName = (oldType.length() ? QStringLiteral("idlSequence") : QStringLiteral("idlString"));
             UMLStereotype *pStereo = m_doc->findStereotype(stereoName);
-            if (pStereo == 0) {
+            if (pStereo == nullptr) {
                 pStereo = m_doc->createStereotype(stereoName);
                 UMLStereotype::AttributeDef tagDef(QStringLiteral("bound"), Uml::PrimitiveTypes::UnlimitedNatural);
                 // Empty bound stands for "unbounded".
@@ -475,10 +475,10 @@ bool IDLImport::parseStmt()
         UMLObject *pNew = Import_Utils::createUMLObject(ot, newType, currentScope(), m_comment,
                                                         QStringLiteral("idlTypedef")); /* stereotype */
         UMLClassifier *newClassifier = pNew->asUMLClassifier();
-        if (oldClassifier == 0) {
+        if (oldClassifier == nullptr) {
             log(QStringLiteral("Error: importIDL(typedef ") + newType +
                 QStringLiteral("): Origin type ") + oldType + QStringLiteral(" is not a classifier"));
-        } else if (newClassifier == 0) {
+        } else if (newClassifier == nullptr) {
             log(QStringLiteral("Error: importIDL(typedef ") + newType +
                 QStringLiteral(") internal error: Import_Utils::createUMLObject did not return a classifier"));
         } else {
@@ -559,18 +559,18 @@ bool IDLImport::parseStmt()
     // (of a member of struct or valuetype, or return type
     // of an operation.) Up next is the name of the attribute
     // or operation.
-    if (! keyword.contains(QRegExp(QStringLiteral("^\\w")))) {
+    if (! keyword.contains(QRegularExpression(QStringLiteral("^\\w")))) {
         log(QStringLiteral("Error: importIDL: ignoring ") + keyword);
         return false;
     }
     QString typeName = joinTypename();
     QString name = advance();
-    if (name.contains(QRegExp(QStringLiteral("\\W")))) {
+    if (name.contains(QRegularExpression(QStringLiteral("\\W")))) {
         log(QStringLiteral("Error: importIDL: expecting name in ") + name);
         return false;
     }
     // At this point we most definitely need a class.
-    if (m_klass == 0) {
+    if (m_klass == nullptr) {
         log(QStringLiteral("Error: importIDL: no class set for ") + name);
         return false;
     }
@@ -617,13 +617,13 @@ bool IDLImport::parseStmt()
         if (m_unionCases.count()) {
             const QString stereoName = QStringLiteral("idlCase");
             UMLStereotype *pStereo = m_doc->findStereotype(stereoName);
-            if (pStereo == 0) {
+            if (pStereo == nullptr) {
                 pStereo = m_doc->createStereotype(stereoName);
                 UMLStereotype::AttributeDef tagDef(QStringLiteral("label"), Uml::PrimitiveTypes::String);
                 pStereo->getAttributeDefs().append(tagDef);
             }
             attr->setUMLStereotype(pStereo);
-            const QString caseLabels = m_unionCases.join(QChar(' '));
+            const QString caseLabels = m_unionCases.join(QLatin1Char(' '));
             attr->tags().append(caseLabels);
             m_unionCases.clear();
         } else if (m_isUnionDefault) {
