@@ -18,7 +18,7 @@
 
 // qt includes
 #include <QFile>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QTextStream>
 
 DEBUG_REGISTER(NativeImportBase)
@@ -34,7 +34,7 @@ NativeImportBase::NativeImportBase(const QString &singleLineCommentIntro, CodeIm
   : ClassImport(thread),
     m_singleLineCommentIntro(singleLineCommentIntro),
     m_srcIndex(0),
-    m_klass(0),
+    m_klass(nullptr),
     m_currentAccess(Uml::Visibility::Public),
     m_inComment(false),
     m_isAbstract(false)
@@ -337,7 +337,7 @@ QStringList NativeImportBase::split(const QString& line)
 {
     QStringList list;
     QString listElement;
-    QChar stringIntro = 0;  // buffers the string introducer character
+    QChar stringIntro;  // buffers the string introducer character
     bool seenSpace = false;
     QString ln = line.trimmed();
     for (int i = 0; i < ln.length(); ++i) {
@@ -348,7 +348,7 @@ QStringList NativeImportBase::split(const QString& line)
                 if (ln[i - 1] != QLatin1Char('\\')) {
                     list.append(listElement);
                     listElement.clear();
-                    stringIntro = 0;  // we are no longer in a string
+                    stringIntro = QChar();  // we are no longer in a string
                 }
             }
         } else if (c == QLatin1Char('"') || c == QLatin1Char('\'')) {
@@ -397,7 +397,7 @@ void NativeImportBase::scan(const QString& line)
             return;
         ln = ln.left(pos);
     }
-    if (ln.contains(QRegExp(QStringLiteral("^\\s*$"))))
+    if (ln.contains(QRegularExpression(QStringLiteral("^\\s*$"))))
         return;
     const QStringList words = split(ln);
     for (QStringList::ConstIterator it = words.begin(); it != words.end(); ++it) {
@@ -429,7 +429,7 @@ void NativeImportBase::initVars()
 bool NativeImportBase::parseFile(const QString& filename)
 {
     QString nameWithoutPath = filename;
-    nameWithoutPath.remove(QRegExp(QStringLiteral("^.*/")));
+    nameWithoutPath.remove(QRegularExpression(QStringLiteral("^.*/")));
     if (m_parsedFiles.contains(nameWithoutPath))
         return true;
     m_parsedFiles.append(nameWithoutPath);
@@ -437,7 +437,7 @@ bool NativeImportBase::parseFile(const QString& filename)
     const QString msgPrefix = filename + QStringLiteral(": ");
     if (filename.contains(QLatin1Char('/'))) {
         QString path = filename;
-        path.remove(QRegExp(QStringLiteral("/[^/]+$")));
+        path.remove(QRegularExpression(QStringLiteral("/[^/]+$")));
         logDebug2("NativeImportBase::parseFile %1 adding path %2", msgPrefix, path);
         Import_Utils::addIncludePath(path);
     }
@@ -487,7 +487,7 @@ bool NativeImportBase::parseFile(const QString& filename)
                          QStringLiteral(" / lines: ") + QString::number(lineCount));
     file.close();
     // Parse the QStringList m_source.
-    m_klass = 0;
+    m_klass = nullptr;
     m_currentAccess = Uml::Visibility::Public;
     m_scope.clear();
     pushScope(Import_Utils::globalScope()); // index 0 is reserved for the global scope
