@@ -39,7 +39,7 @@ class UMLClassifier;
 class NativeImportBase : public ClassImport
 {
 public:
-    explicit NativeImportBase(const QString &singleLineCommentIntro, CodeImpThread* thread = 0);
+    explicit NativeImportBase(const QString &singleLineCommentIntro, CodeImpThread *thread = nullptr);
     virtual ~NativeImportBase();
 
 protected:
@@ -75,7 +75,7 @@ protected:
      */
     virtual bool parseStmt() = 0;
 
-    void skipStmt(const QString& until = QLatin1String(";"));
+    void skipStmt(const QString& until = QStringLiteral(";"));
     bool skipToClosing(QChar opener);
 
     QString current();
