@@ -71,14 +71,14 @@ public:
 
     bool logToConsole();
 
-    static void registerClass(const char * name, bool state=true, const char * filePath=0);
+    static void registerClass(const char * name, bool state=true, const char *filePath = nullptr);
 
 protected:
     void update(const QString &name);
     void updateParentItemCheckBox(QTreeWidgetItem *parent);
     virtual void showEvent(QShowEvent*);
 
-private slots:
+private Q_SLOTS:
     void slotParentItemClicked(QTreeWidgetItem *parent);
     void slotItemClicked(QTreeWidgetItem* item, int column);
 
@@ -99,7 +99,7 @@ private:
     static StateMap* s_states;
     static bool s_logToConsole;
 
-    explicit Tracer(QWidget *parent = 0);
+    explicit Tracer(QWidget  *parent = nullptr);
 };
 
 // convenience macros for console output to the Umbrello area
