@@ -26,7 +26,7 @@
 #include <QListWidget>
 #include <QMap>
 #include <QMimeData>
-#include <QRegExp>
+#include <QRegularExpression>
 
 // Currently this file is not using debug statements. Activate this line when inserting them:
 DEBUG_REGISTER_DISABLED(Diagram_Utils)
@@ -42,7 +42,7 @@ SequenceLineFormat detectSequenceLineFormat(const QStringList &lines)
 {
     QStringList l = lines;
     while(l.size() > 0) {
-        QStringList cols = l.takeFirst().split(QRegExp(QStringLiteral("\\s+")),QString::SkipEmptyParts);
+        QStringList cols = l.takeFirst().split(QRegularExpression(QStringLiteral("\\s+")),Qt::SkipEmptyParts);
         if (cols.size() < 1)
             continue;
 
@@ -85,7 +85,7 @@ bool parseSequenceLine(const QString &s, QString &sequence, QString &package, QS
 {
     QString identifier;
     QString module;
-    QStringList cols = s.split(QRegExp(QStringLiteral("\\s+")),QString::SkipEmptyParts);
+    QStringList cols = s.split(QRegularExpression(QStringLiteral("\\s+")),Qt::SkipEmptyParts);
     if (cols.size() < 1) {
         error = QStringLiteral("could not parse");
         return false;
@@ -205,7 +205,7 @@ bool importSequences(const QStringList &lines, UMLScene *scene, const QString &s
     QString name(QStringLiteral("client"));
     UMLObject *left = umldoc->findUMLObject(name, UMLObject::ot_Class);
     if (!left ) {
-        left = new UMLObject(0, name);
+        left = new UMLObject(nullptr, name);
         left->setBaseType(UMLObject::ot_Class);
     }
 
@@ -215,23 +215,23 @@ bool importSequences(const QStringList &lines, UMLScene *scene, const QString &s
     scene->addWidgetCmd(leftWidget);
     objectsMap[name] = leftWidget;
 
-    ObjectWidget *rightWidget = 0;
+    ObjectWidget *rightWidget = nullptr;
     ObjectWidget *mostRightWidget = leftWidget;
-    MessageWidget *messageWidget = 0;
+    MessageWidget *messageWidget = nullptr;
     // for further processing
     MessageWidgetList messages;
 
     QStringList l;
     SequenceLineFormat format = detectSequenceLineFormat(lines);
     if (format == GDB || format == QtCreatorGDB)
-        foreach(const QString &s, lines)
+        for(const QString &s : lines)
             l.push_front(s);
     else
         l = lines;
 
     // for each line
     int index = 1;
-    foreach(const QString &line, l) {
+    for(const QString &line : l) {
         QString stackframe, package, method, error;
 
         if (!parseSequenceLine(line, stackframe, package, method, error)) {
@@ -286,13 +286,13 @@ bool importSequences(const QStringList &lines, UMLScene *scene, const QString &s
         return false;
 
     // adjust vertical position
-    foreach(MessageWidget *w, messages) {
+    for(MessageWidget *w : messages) {
         w->setY(w->y() + 20);
     }
 
     // adjust heights starting from the last message
     MessageWidget *previous = messages.takeFirst();
-    foreach(MessageWidget *w, messages) {
+    for(MessageWidget *w : messages) {
         w->setSize(w->width(), previous->y() - w->y() + previous->height() + 5);
         // adjust vertical line length of object widgets
         w->objectWidget(Uml::RoleType::A)->slotMessageMoved();
@@ -306,13 +306,13 @@ bool importClassGraph(const QStringList &lines, UMLScene *scene, const QString &
 {
     UMLDoc *umldoc = UMLApp::app()->document();
 
-    UMLWidget *lastWidget = 0;
-    UMLClassifier *c = 0;
+    UMLWidget *lastWidget = nullptr;
+    UMLClassifier *c = nullptr;
     QString methodIdentifier(QStringLiteral("()"));
     QMap<QString, QPointer<UMLWidget>> widgetList;
     int lineNumber = 0;
     // for each line
-    foreach(const QString &line, lines) {
+    for(const QString &line: lines) {
         lineNumber++;
         if (line.trimmed().isEmpty() || line.startsWith(QLatin1Char('#')) || line.startsWith(QStringLiteral("//")))
             continue;
@@ -340,7 +340,7 @@ bool importClassGraph(const QStringList &lines, UMLScene *scene, const QString &
                 o2 = Object_Factory::createUMLObject(UMLObject::ot_Class, l[2]);
             bool swapObjects = false;
             Uml::AssociationType::Enum type = Uml::AssociationType::Unknown;
-            UMLAssociation *assoc = 0;
+            UMLAssociation  *assoc = nullptr;
             bool newAssoc = false;
             if (l[1] == QStringLiteral("---")) {
                 type = Uml::AssociationType::Association;
@@ -355,8 +355,8 @@ bool importClassGraph(const QStringList &lines, UMLScene *scene, const QString &
             } else if (l[1] == QStringLiteral("-|>")) {
                 type = Uml::AssociationType::Generalization;
             }
-            QPointer<UMLWidget> w1 = 0;
-            QPointer<UMLWidget> w2 = 0;
+            QPointer<UMLWidget> w1 = nullptr;
+            QPointer<UMLWidget> w2 = nullptr;
             bool error = false;
             if (swapObjects) {
                 w1 = widgetList[l[2]];
@@ -522,7 +522,7 @@ bool importGraph(const QString &fileName, UMLScene *scene)
 bool isUniqueDiagramName(Uml::DiagramType::Enum type, QString &name)
 {
     bool found = false;
-    foreach (UMLView *view, UMLApp::app()->document()->viewIterator()) {
+    for(UMLView  *view : UMLApp::app()->document()->viewIterator()) {
         if (type == Uml::DiagramType::Undefined || view->umlScene()->type() == type) {
             if (view->umlScene()->name() == name)
                 found = true;
