@@ -25,7 +25,7 @@ public:
 protected:
     void setupPages();
 
-protected slots:
+protected Q_SLOTS:
     void slotOk();
     void slotApply();
 
