@@ -42,15 +42,15 @@ DEBUG_REGISTER(MultiPageDialogBase)
  */
 MultiPageDialogBase::MultiPageDialogBase(QWidget *parent, bool withDefaultButton)
   : QWidget(parent),
-    m_pAssocGeneralPage(0),
-    m_notePage(0),
-    m_operationGeneralPage(0),
-    m_pRolePage(0),
-    m_fontChooser(0),
-    m_pStylePage(0),
-    m_pageItem(0),
-    m_pageDialog(0),
-    m_pageWidget(0),
+    m_pAssocGeneralPage(nullptr),
+    m_notePage(nullptr),
+    m_operationGeneralPage(nullptr),
+    m_pRolePage(nullptr),
+    m_fontChooser(nullptr),
+    m_pStylePage(nullptr),
+    m_pageItem(nullptr),
+    m_pageDialog(nullptr),
+    m_pageWidget(nullptr),
     m_useDialog(!parent || strcmp(parent->metaObject()->className(),"PropertiesWindow") != 0),
     m_isModified(false)
 {
@@ -183,7 +183,7 @@ bool MultiPageDialogBase::isModified() const
  */
 void MultiPageDialogBase::slotOkClicked()
 {
-    emit okClicked();
+    Q_EMIT okClicked();
 }
 
 /**
@@ -191,7 +191,7 @@ void MultiPageDialogBase::slotOkClicked()
  */
 void MultiPageDialogBase::slotApplyClicked()
 {
-    emit applyClicked();
+    Q_EMIT applyClicked();
 }
 
 /**
@@ -199,7 +199,7 @@ void MultiPageDialogBase::slotApplyClicked()
  */
 void MultiPageDialogBase::slotDefaultClicked()
 {
-    emit defaultClicked();
+    Q_EMIT defaultClicked();
 }
 
 /**
@@ -332,7 +332,7 @@ void MultiPageDialogBase::setupGeneralPage(NoteWidget *widget)
  */
 KPageWidgetItem *MultiPageDialogBase::setupFontPage(const QFont &font)
 {
-    m_fontChooser = new KFontChooser(0, KFontChooser::NoDisplayFlags, QStringList(), 0);
+    m_fontChooser = new KFontChooser(KFontChooser::NoDisplayFlags, this);
     m_fontChooser->enableColumn(KFontChooser::StyleList, false);
     m_fontChooser->setFont(font);
     return createPage(i18n("Font"), i18n("Font Settings"),
@@ -409,7 +409,7 @@ void MultiPageDialogBase::applyFontPage(UMLWidget *widget)
  */
 KPageWidgetItem *MultiPageDialogBase::setupStylePage(WidgetBase *widget)
 {
-    m_pStylePage = new UMLWidgetStylePage(0, widget);
+    m_pStylePage = new UMLWidgetStylePage(nullptr, widget);
     return createPage(i18nc("widget style page", "Style"), i18n("Widget Style"),
                       Icon_Utils::it_Properties_Color, m_pStylePage);
 }
@@ -420,7 +420,7 @@ KPageWidgetItem *MultiPageDialogBase::setupStylePage(WidgetBase *widget)
  */
 KPageWidgetItem *MultiPageDialogBase::setupStylePage(AssociationWidget *widget)
 {
-    m_pStylePage = new UMLWidgetStylePage(0, widget);
+    m_pStylePage = new UMLWidgetStylePage(nullptr, widget);
     return createPage(i18nc("style page name", "Style"), i18n("Line Style"),
                       Icon_Utils::it_Properties_Color, m_pStylePage);
 }
@@ -440,7 +440,7 @@ void MultiPageDialogBase::applyStylePage()
  */
 KPageWidgetItem *MultiPageDialogBase::setupAssociationRolePage(AssociationWidget *widget)
 {
-    m_pRolePage = new AssociationRolePage(0, widget);
+    m_pRolePage = new AssociationRolePage(nullptr, widget);
     return createPage(i18nc("role page name", "Roles"), i18n("Role Settings"),
                       Icon_Utils::it_Properties_Roles, m_pRolePage);
 }
