@@ -17,7 +17,7 @@ class CodeGenerationPolicyPage : public DialogPageBase
 {
     Q_OBJECT
 public:
-    explicit CodeGenerationPolicyPage (QWidget *parent=0, const char *name=0, CodeGenPolicyExt * policy = 0);
+    explicit CodeGenerationPolicyPage (QWidget *parent = nullptr, const char *name=nullptr, CodeGenPolicyExt *policy = nullptr);
 
     virtual ~CodeGenerationPolicyPage();
 
@@ -27,7 +27,7 @@ protected:
 
     CodeGenPolicyExt * m_parentPolicy;
 
-public slots:
+public Q_SLOTS:
 
     virtual void apply();
 
