@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2003-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2003-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #ifndef CONSTRAINTLISTPAGE_H
@@ -13,13 +13,8 @@
 //qt  includes
 #include <QWidget>
 
-#if QT_VERSION < 0x050000
-class KAction;
-class KMenu;
-#else
 class QAction;
 class QMenu;
-#endif
 
 /**
  * A dialog page to display entity constraint properties.
@@ -39,20 +34,13 @@ public:
 
 private:
 
-#if QT_VERSION >= 0x050000
     QAction* newUniqueConstraintAction;
     QAction* newPrimaryKeyConstraintAction;
     QAction* newForeignKeyConstraintAction;
     QAction* newCheckConstraintAction;
-#else
-    KAction* newUniqueConstraintAction;
-    KAction* newPrimaryKeyConstraintAction;
-    KAction* newForeignKeyConstraintAction;
-    KAction* newCheckConstraintAction;
-#endif
     void setupActions();
 
-private slots:
+private Q_SLOTS:
 
     void slotNewUniqueConstraint();
     void slotNewPrimaryKeyConstraint();
@@ -64,11 +52,7 @@ protected:
 
     bool greaterThan(UMLObject::ObjectType ct1, UMLObject::ObjectType ct2);
 
-#if QT_VERSION >= 0x050000
     QMenu* buttonMenu;
-#else
-    KMenu* buttonMenu;
-#endif
 
 };
 
