@@ -18,11 +18,12 @@
 #include <kjobwidgets.h>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <kio/job.h>
+#include <KIO/Job>
+#include <KIO/FileCopyJob>
 
 #include <QApplication>
 #include <QFile>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QTextStream>
 
 DEBUG_REGISTER(DocbookGenerator)
@@ -35,7 +36,7 @@ DocbookGenerator::DocbookGenerator()
   umlDoc = UMLApp::app()->document();
   m_pStatus = true;
   m_pThreadFinished = false;
-  docbookGeneratorJob = 0;
+  docbookGeneratorJob = nullptr;
 }
 
 /**
@@ -58,7 +59,7 @@ bool DocbookGenerator::generateDocbookForProject()
 {
     QUrl url = umlDoc->url();
   QString fileName = url.fileName();
-  fileName.remove(QRegExp(QStringLiteral(".xmi$")));
+  fileName.remove(QRegularExpression(QStringLiteral(".xmi$")));
   url.setPath(url.path() + QLatin1Char('/') + fileName);
   logDebug1("DocbookGenerator::generateDocbookForProject: Exporting to directory %1", url.path());
   generateDocbookForProjectInto(url);
@@ -99,7 +100,7 @@ void DocbookGenerator::slotDocbookGenerationFinished(const QString& tmpFileName)
     logDebug1("DocbookGenerator: Generation finished (%1)", tmpFileName);
     QUrl url = umlDoc->url();
     QString fileName = url.fileName();
-    fileName.replace(QRegExp(QStringLiteral(".xmi$")), QStringLiteral(".docbook"));
+    fileName.replace(QRegularExpression(QStringLiteral(".xmi$")), QStringLiteral(".docbook"));
     url.setPath(m_destDir.path() + QLatin1Char('/') + fileName);
     KIO::Job* job = KIO::file_copy(QUrl::fromLocalFile(tmpFileName), url, -1, KIO::Overwrite | KIO::HideProgressInfo);
     KJobWidgets::setWindow(job, (QWidget*)UMLApp::app());
@@ -117,14 +118,14 @@ void DocbookGenerator::slotDocbookGenerationFinished(const QString& tmpFileName)
         qApp->processEvents();
     }
 
-    emit finished(m_pStatus);
+    Q_EMIT finished(m_pStatus);
 }
 
 void DocbookGenerator::threadFinished()
 {
     m_pThreadFinished = true;
     delete docbookGeneratorJob;
-    docbookGeneratorJob = 0;
+    docbookGeneratorJob = nullptr;
 }
 
 /**
