@@ -9,7 +9,7 @@
 #include <QWidget>
 
 class AssociationWidget;
-class KTextEdit;
+class QTextEdit;
 class ModifiedWidget;
 class QLabel;
 class UMLObject;
@@ -25,7 +25,7 @@ class DocWindow : public QWidget
 {
     Q_OBJECT
 public:
-    explicit DocWindow(UMLDoc * doc, QWidget *parent = 0);
+    explicit DocWindow(UMLDoc * doc, QWidget *parent = nullptr);
     ~DocWindow();
 
     void showDocumentation(UMLObject * object, bool overwrite = false);
@@ -40,11 +40,11 @@ public:
     bool isTyping() const;
     void setFocus();
 
-public slots:
+public Q_SLOTS:
     void slotAssociationRemoved(AssociationWidget* association);
     void slotWidgetRemoved(UMLWidget* widget);
 
-private slots:
+private Q_SLOTS:
     void slotTextChanged();
     void slotFocusEnabledChanged(int state);
 
@@ -72,7 +72,7 @@ private:
     QLabel    *m_typeLabel;      ///< label for type icon
     QLabel    *m_nameLabel;      ///< label for name text
     ModifiedWidget *m_modifiedWidget;  ///< label for modified flag icon
-    KTextEdit *m_docTE;          ///< documentation widget
+    QTextEdit *m_docTE;          ///< documentation widget
     bool m_focusEnabled;
 
     bool isModified() const;
