@@ -1,24 +1,19 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   copyright (C) 2014                                                    *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2014-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 #ifndef UMLFINDER_H
 #define UMLFINDER_H
 
-#include "findresults.h"
-
 // app include
 #include "basictypes.h"
 
 // qt include
 #include <QList>
 
+class UMLObject;
+
 /**
  * The UMLFinder class provides the interface for find related classes.
  *
@@ -27,7 +22,8 @@
 class UMLFinder
 {
 public:
-    typedef enum { All } Category;
+    typedef enum { All, Classes, Packages, Interfaces, Operations, Attributes } Category;
+    typedef enum { TreeView, CurrentDiagram, AllDiagrams } Filter;
     typedef enum { Empty, End, Found, NotFound } Result;
     UMLFinder();
     virtual ~UMLFinder();
@@ -57,6 +53,8 @@ public:
 protected:
     int m_index;
     QList<Uml::ID::Type> m_items;
+
+    bool includeObject(Category category, UMLObject *o);
 };
 
 #endif // UMLFINDER_H
