@@ -16,15 +16,15 @@ class ObjectsWindow : public QDockWidget
 {
     Q_OBJECT
 public:
-    explicit ObjectsWindow(const QString &title, QWidget *parent = 0);
+    explicit ObjectsWindow(const QString &title, QWidget  *parent = nullptr);
     ~ObjectsWindow();
 
-signals:
+Q_SIGNALS:
 
-public slots:
+public Q_SLOTS:
     void modified();
 
-protected slots:
+protected Q_SLOTS:
     void slotObjectsDoubleClicked(QModelIndex index);
     void slotObjectsClicked(QModelIndex index);
 
