@@ -25,16 +25,16 @@ class RefactoringAssistant : public QTreeWidget
     Q_OBJECT
 public:
 
-    explicit RefactoringAssistant(UMLDoc *doc, UMLClassifier *obj = 0, QWidget *parent = 0, const QString &name = QString());
+    explicit RefactoringAssistant(UMLDoc *doc, UMLClassifier *obj = nullptr, QWidget *parent = nullptr, const QString &name = QString());
     virtual ~RefactoringAssistant();
 
     void refactor(UMLClassifier *obj);
 
-signals:
+Q_SIGNALS:
 
 //    void moved();
 
-public slots:
+public Q_SLOTS:
 
     void addBaseClassifier();
     void addDerivedClassifier();
@@ -64,7 +64,7 @@ protected:
 
     void deleteItem(QTreeWidgetItem *item, UMLObject *obj);
 
-    void addClassifier(UMLClassifier *classifier, QTreeWidgetItem *parent = 0, bool addSuper = true, bool addSub = true, bool recurse = false);
+    void addClassifier(UMLClassifier  *classifier, QTreeWidgetItem *parent = nullptr, bool addSuper = true, bool addSub = true, bool recurse = false);
 
     virtual void dragMoveEvent(QDragMoveEvent *event);
     virtual void dropEvent(QDropEvent *event);
@@ -77,7 +77,7 @@ protected:
     QMap<QTreeWidgetItem*, UMLObject*>  m_umlObjectMap;
     QSet<UMLClassifier *>               m_alreadySeen; ///< recursive guard
 
-private slots:
+private Q_SLOTS:
 
     void showContextMenu(const QPoint&);
 
