@@ -77,7 +77,7 @@ UMLAttribute::~UMLAttribute()
 void UMLAttribute::setName(const QString &name)
 {
     m_name = name;
-    emit attributeChanged();
+    Q_EMIT attributeChanged();
     UMLObject::emitModified();
 }
 
@@ -88,7 +88,7 @@ void UMLAttribute::setName(const QString &name)
 void UMLAttribute::setVisibility(Uml::Visibility::Enum s)
 {
     m_visibility = s;
-    emit attributeChanged();
+    Q_EMIT attributeChanged();
     UMLObject::emitModified();
 }
 
@@ -149,7 +149,7 @@ QString UMLAttribute::toString(Uml::SignatureType::Enum sig, bool withStereotype
             owningObject = owningObject->umlParent();
         }
         const UMLClassifier *ownParent = owningObject->asUMLClassifier();
-        if (ownParent == 0) {
+        if (ownParent == nullptr) {
             logError2("UMLAttribute::toString(%1): parent %2 is not a UMLClassifier",
                       name(), owningObject->name());
             return QString();
@@ -190,14 +190,14 @@ QString UMLAttribute::toString(Uml::SignatureType::Enum sig, bool withStereotype
 QString UMLAttribute::getFullyQualifiedName(const QString& separator,
                                             bool includeRoot /* = false */) const
 {
-    const UMLOperation *op = 0;
+    const UMLOperation  *op = nullptr;
     UMLObject *owningObject = umlParent();
     if (owningObject->baseType() == UMLObject::ot_Operation) {
         op = owningObject->asUMLOperation();
         owningObject = owningObject->umlParent();
     }
     UMLClassifier *ownParent = owningObject->asUMLClassifier();
-    if (ownParent == 0) {
+    if (ownParent == nullptr) {
         logError2("UMLAttribute::getFullyQualifiedName(%1): parent %2 is not a UMLClassifier",
                   name(), owningObject->name());
         return QString();
@@ -270,7 +270,7 @@ void UMLAttribute::saveToXMI(QXmlStreamWriter& writer)
     } else {
         UMLObject::save1(writer, QStringLiteral("Attribute"));
     }
-    if (m_pSecondary == 0) {
+    if (m_pSecondary == nullptr) {
         logDebug2("UMLAttribute::saveToXMI(%1) : m_pSecondary is null, m_SecondaryId is '%2'",
                   name(), m_SecondaryId);
     } else {
@@ -324,7 +324,7 @@ bool UMLAttribute::load1(QDomElement & element)
                 bool isPrimitive = (xmiType.isEmpty() ?
                                     href.contains(QStringLiteral("PrimitiveType")) :
                                     xmiType.contains(QStringLiteral("PrimitiveType")));
-                if (isPrimitive && href.contains(QRegExp(QStringLiteral("#[A-Za-z][a-z]+$")))) {
+                if (isPrimitive && href.contains(QRegularExpression(QStringLiteral("#[A-Za-z][a-z]+$")))) {
                     // Example from OMG XMI:
                     //   <type xmi:type="uml:PrimitiveType" href="http://www.omg.org/spec/UML/20090901/UML.xmi#Boolean"/>
                     // Example from MagicDraw:
@@ -416,10 +416,10 @@ void UMLAttribute::setTemplateParams(const QString& templateParam, UMLClassifier
             if (!param.isEmpty()) {
                 UMLDoc *pDoc = UMLApp::app()->document();
                 UMLObject* obj = pDoc->findUMLObject(param);
-                if (obj == 0) {
+                if (obj == nullptr) {
                     obj = pDoc->findUMLObject(param.remove(QLatin1Char(' ')));
                 }
-                if (obj != 0) {
+                if (obj != nullptr) {
                     //We want to list only the params that already exist in this document
                     //If the param doesn't already exist, we couldn't draw an association anyway
                     UMLClassifier* tmpClassifier = obj->asUMLClassifier();
