@@ -27,7 +27,7 @@ public:
     UMLAttribute(UMLObject *parent, const QString& name,
                  Uml::ID::Type id = Uml::ID::None,
                  Uml::Visibility::Enum s = Uml::Visibility::Private,
-                 UMLObject *type = 0, const QString& iv = QString());
+                 UMLObject *type = nullptr, const QString& iv = QString());
     explicit UMLAttribute(UMLObject *parent);
 
     bool operator==(const UMLAttribute &rhs) const;
@@ -53,14 +53,14 @@ public:
 
     virtual void saveToXMI(QXmlStreamWriter& writer);
 
-    virtual bool showPropertiesDialog(QWidget* parent = 0);
+    virtual bool showPropertiesDialog(QWidget *parent = nullptr);
 
     void setParmKind(Uml::ParameterDirection::Enum pk);
     Uml::ParameterDirection::Enum getParmKind() const;
 
     virtual UMLClassifierList getTemplateParams();
 
-signals:
+Q_SIGNALS:
 
     void attributeChanged();
 
