@@ -63,7 +63,7 @@ UMLClassifier::UMLClassifier(const QString & name, Uml::ID::Type id)
   : UMLPackage(name, id)
 {
     m_BaseType = UMLObject::ot_Class;  // default value
-    m_pClassAssoc = 0;
+    m_pClassAssoc = nullptr;
 }
 
 /**
@@ -136,12 +136,12 @@ UMLOperation * UMLClassifier::checkOperationSignature(
 {
     UMLOperationList list = findOperations(name);
     if (list.count() == 0) {
-        return 0;
+        return nullptr;
     }
     const int inputParmCount = opParams.count();
 
     // there is at least one operation with the same name... compare the parameter list
-    foreach (UMLOperation* test, list) {
+    for(UMLOperation* test : list) {
         if (test == exemptOp) {
             continue;
         }
@@ -163,7 +163,7 @@ UMLOperation * UMLClassifier::checkOperationSignature(
         }
     }
     // we did not find an exact match, so the signature is unique (acceptable)
-    return 0;
+    return nullptr;
 }
 
 /**
@@ -179,12 +179,12 @@ UMLOperation* UMLClassifier::findOperation(const QString& name,
 {
     UMLOperationList list = findOperations(name);
     if (list.count() == 0) {
-        return 0;
+        return nullptr;
     }
     // if there are operation(s) with the same name then compare the parameter list
     const int inputParmCount = params.count();
 
-    foreach (UMLOperation* test, list) {
+    for(UMLOperation* test : list) {
         UMLAttributeList testParams = test->getParmList();
         const int pCount = testParams.count();
         if (inputParmCount == 0 && pCount == 0)
@@ -196,9 +196,9 @@ UMLOperation* UMLClassifier::findOperation(const QString& name,
             Model_Utils::NameAndType_ListIt nt(params.begin() + i);
             UMLClassifier *type = (*nt).m_type->asUMLClassifier();
             UMLClassifier *testType = testParams.at(i)->getType();
-            if (type == 0 && testType == 0) { //no parameter type
+            if (type == nullptr && testType == nullptr) { //no parameter type
                 continue;
-            } else if (type == 0) {  //template parameter
+            } else if (type == nullptr) {  //template parameter
                 if (testType->name() != QStringLiteral("class"))
                     break;
             } else if (type != testType)
@@ -207,7 +207,7 @@ UMLOperation* UMLClassifier::findOperation(const QString& name,
         if (i == pCount)
             return test;  // all parameters matched
     }
-    return 0;
+    return nullptr;
 }
 
 /**
@@ -233,8 +233,8 @@ UMLOperation* UMLClassifier::findOperation(const QString& name,
  */
 UMLOperation* UMLClassifier::createOperation(
         const QString &name /*=QString()*/,
-        bool *isExistingOp  /*=0*/,
-        Model_Utils::NameAndType_List *params  /*=0*/)
+        bool  *isExistingOp  /*= nullptr*/,
+        Model_Utils::NameAndType_List  *params  /*= nullptr*/)
 {
     bool nameNotSet = (name.isNull() || name.isEmpty());
     if (! nameNotSet) {
@@ -242,8 +242,8 @@ UMLOperation* UMLClassifier::createOperation(
         if (params)
             parList = *params;
         UMLOperation* existingOp = findOperation(name, parList);
-        if (existingOp != 0) {
-            if (isExistingOp != 0)
+        if (existingOp != nullptr) {
+            if (isExistingOp != nullptr)
                 *isExistingOp = true;
             return existingOp;
         }
@@ -271,13 +271,13 @@ UMLOperation* UMLClassifier::createOperation(
         op->setName(uniqChildName(UMLObject::ot_Operation));
 
         while (true) {
-            QPointer<UMLOperationDialog> operationDialog = new UMLOperationDialog(0, op);
+            QPointer<UMLOperationDialog> operationDialog = new UMLOperationDialog(nullptr, op);
             if(operationDialog->exec() != QDialog::Accepted) {
                 delete op;
                 delete operationDialog;
-                return 0;
+                return nullptr;
             } else if (checkOperationSignature(op->name(), op->getParmList())) {
-                KMessageBox::information(0,
+                KMessageBox::information(nullptr,
                                          i18n("An operation with the same name and signature already exists. You cannot add it again."));
             } else {
                 break;
@@ -289,7 +289,7 @@ UMLOperation* UMLClassifier::createOperation(
     // operation name is ok, formally add it to the classifier
     if (! addOperation(op)) {
         delete op;
-        return 0;
+        return nullptr;
     }
 
     UMLDoc *umldoc = UMLApp::app()->document();
@@ -323,7 +323,7 @@ bool UMLClassifier::addOperation(UMLOperation* op, int position)
         subordinates().insert(position, op);
         UMLClassifierListItemList itemList = getFilteredList(UMLObject::ot_Operation);
         QString buf;
-        foreach (UMLClassifierListItem* currentAtt, itemList) {
+        for(UMLClassifierListItem* currentAtt : itemList) {
             buf.append(QLatin1Char(' ') + currentAtt->name());
         }
         logDebug1("UMLClassifier::addOperation list after change:%1", buf);
@@ -331,7 +331,7 @@ bool UMLClassifier::addOperation(UMLOperation* op, int position)
     else {
         subordinates().append(op);
     }
-    emit operationAdded(op);
+    Q_EMIT operationAdded(op);
     UMLObject::emitModified();
     connect(op, SIGNAL(modified()), this, SIGNAL(modified()));
     return true;
@@ -368,7 +368,7 @@ bool UMLClassifier::addOperation(UMLOperation* op, IDChangeLog* log)
  */
 int UMLClassifier::removeOperation(UMLOperation *op)
 {
-    if (op == 0) {
+    if (op == nullptr) {
         logDebug0("UMLClassifier::removeOperation called on NULL op");
         return -1;
     }
@@ -379,7 +379,7 @@ int UMLClassifier::removeOperation(UMLOperation *op)
     // disconnection needed.
     // note that we don't delete the operation, just remove it from the Classifier
     disconnect(op, SIGNAL(modified()), this, SIGNAL(modified()));
-    emit operationRemoved(op);
+    Q_EMIT operationRemoved(op);
     UMLObject::emitModified();
     return subordinates().count();
 }
@@ -401,15 +401,15 @@ UMLObject* UMLClassifier::createTemplate(const QString& currentName /*= QString(
     int button = QDialog::Accepted;
 
     while (button == QDialog::Accepted && !goodName) {
-        QPointer<UMLTemplateDialog> templateDialog = new UMLTemplateDialog(0, newTemplate);
+        QPointer<UMLTemplateDialog> templateDialog = new UMLTemplateDialog(nullptr, newTemplate);
         button = templateDialog->exec();
         name = newTemplate->name();
 
         if (name.length() == 0) {
-            KMessageBox::error(0, i18n("That is an invalid name."), i18n("Invalid Name"));
+            KMessageBox::error(nullptr, i18n("That is an invalid name."), i18n("Invalid Name"));
         }
-        else if (findChildObject(name) != 0) {
-            KMessageBox::error(0, i18n("That name is already being used."), i18n("Not a Unique Name"));
+        else if (findChildObject(name) != nullptr) {
+            KMessageBox::error(nullptr, i18n("That name is already being used."), i18n("Not a Unique Name"));
         }
         else {
             goodName = true;
@@ -418,7 +418,7 @@ UMLObject* UMLClassifier::createTemplate(const QString& currentName /*= QString(
     }
 
     if (button != QDialog::Accepted) {
-        return 0;
+        return nullptr;
     }
 
     addTemplate(newTemplate);
@@ -435,7 +435,7 @@ UMLObject* UMLClassifier::createTemplate(const QString& currentName /*= QString(
 UMLAttributeList UMLClassifier::getAttributeList() const
 {
     UMLAttributeList attributeList;
-    foreach (UMLObject* listItem, subordinates()) {
+    for(UMLObject* listItem : subordinates()) {
         if (listItem->baseType() == UMLObject::ot_Attribute) {
             attributeList.append(listItem->asUMLAttribute());
         }
@@ -454,7 +454,7 @@ UMLAttributeList UMLClassifier::getAttributeList(Visibility::Enum scope) const
     if (!isInterface())
     {
         UMLAttributeList atl = getAttributeList();
-        foreach(UMLAttribute* at, atl)
+        for(UMLAttribute* at : atl)
         {
             uIgnoreZeroPointer(at);
             if (! at->isStatic())
@@ -489,7 +489,7 @@ UMLAttributeList UMLClassifier::getAttributeListStatic(Visibility::Enum scope) c
     if (!isInterface())
     {
         UMLAttributeList atl = getAttributeList();
-        foreach(UMLAttribute* at, atl)
+        for(UMLAttribute* at : atl)
         {
             uIgnoreZeroPointer(at);
             if (at->isStatic())
@@ -522,7 +522,7 @@ UMLOperationList UMLClassifier::findOperations(const QString &n) const
 {
     const bool caseSensitive = UMLApp::app()->activeLanguageIsCaseSensitive();
     UMLOperationList list;
-    foreach (UMLObject*  obj, subordinates()) {
+    for(UMLObject*  obj : subordinates()) {
         if (obj->baseType() != UMLObject::ot_Operation)
             continue;
         UMLOperation *op = obj->asUMLOperation();
@@ -551,14 +551,14 @@ UMLObject* UMLClassifier::findChildObjectById(Uml::ID::Type id,
     }
     if (considerAncestors) {
         UMLClassifierList ancestors = findSuperClassConcepts();
-        foreach (UMLClassifier *anc, ancestors) {
+        for(UMLClassifier *anc : ancestors) {
             UMLObject *o = anc->findChildObjectById(id);
             if (o) {
                 return o;
             }
         }
     }
-    return 0;
+    return nullptr;
 }
 
 /**
@@ -574,7 +574,7 @@ UMLClassifierList UMLClassifier::findSubClassConcepts (ClassifierType type) cons
 
     UMLClassifierList inheritingConcepts;
     Uml::ID::Type myID = id();
-    foreach(UMLClassifier *c, list) {
+    for(UMLClassifier *c : list) {
         uIgnoreZeroPointer(c);
         if (type == ALL || (!c->isInterface() && type == CLASS)
                 || (c->isInterface() && type == INTERFACE)) {
@@ -582,7 +582,7 @@ UMLClassifierList UMLClassifier::findSubClassConcepts (ClassifierType type) cons
         }
     }
 
-    foreach (UMLAssociation *a, rlist) {
+    for(UMLAssociation *a : rlist) {
         uIgnoreZeroPointer(a);
         if (a->getObjectId(RoleType::A) != myID)
         {
@@ -613,14 +613,14 @@ UMLClassifierList UMLClassifier::findSuperClassConcepts (ClassifierType type) co
 
     UMLClassifierList parentConcepts;
     Uml::ID::Type myID = id();
-    foreach (UMLClassifier *classifier, list) {
+    for (UMLClassifier *classifier :  list) {
         uIgnoreZeroPointer(classifier);
         if (type == ALL || (!classifier->isInterface() && type == CLASS)
                 || (classifier->isInterface() && type == INTERFACE))
             parentConcepts.append(classifier);
     }
 
-    foreach (UMLAssociation *a, rlist) {
+    for(UMLAssociation *a : rlist) {
         if (a->getObjectId(RoleType::A) == myID)
         {
             UMLObject* obj = a->getObject(RoleType::B);
@@ -646,7 +646,7 @@ void UMLClassifier::copyInto(UMLObject *lhs) const
     target->setBaseType(m_BaseType);
     // CHECK: association property m_pClassAssoc is not copied
     subordinates().copyInto(&(target->subordinates()));
-    foreach(UMLObject *o, target->subordinates()) {
+    for(UMLObject *o : target->subordinates()) {
         o->setUMLParent(target);
     }
 }
@@ -670,7 +670,7 @@ void UMLClassifier::setNameCmd(const QString &strName)
     if (UMLApp::app()->activeLanguage() == Uml::ProgrammingLanguage::Cpp ||
             UMLApp::app()->activeLanguage() == Uml::ProgrammingLanguage::CSharp ||
             UMLApp::app()->activeLanguage() == Uml::ProgrammingLanguage::Java) {
-        foreach(UMLOperation *op, getOpList()) {
+        for(UMLOperation *op : getOpList()) {
             if (op->isConstructorOperation())
                 op->setNameCmd(strName);
             if (op->isDestructorOperation())
@@ -692,7 +692,7 @@ bool UMLClassifier::resolveRef()
 {
     bool success = UMLPackage::resolveRef();
     // Using reentrant iteration is a bare necessity here:
-    foreach (UMLObject* obj, subordinates()) {
+    for(UMLObject* obj : subordinates()) {
         /**** For reference, here is the non-reentrant iteration scheme -
               DO NOT USE THIS !
         for (UMLObject *obj = subordinates().first(); obj; obj = subordinates().next())
@@ -704,13 +704,13 @@ bool UMLClassifier::resolveRef()
                 continue;
             switch (cli->baseType()) {
                 case UMLObject::ot_Attribute:
-                    emit attributeAdded(cli);
+                    Q_EMIT attributeAdded(cli);
                     break;
                 case UMLObject::ot_Operation:
-                    emit operationAdded(cli);
+                    Q_EMIT operationAdded(cli);
                     break;
                 case UMLObject::ot_Template:
-                    emit templateAdded(cli);
+                    Q_EMIT templateAdded(cli);
                     break;
                 default:
                     break;
@@ -773,14 +773,14 @@ UMLAttribute* UMLClassifier::createAttribute(const QString &name,
     //check for name.isNull() stops dialog being shown
     //when creating attribute via list view
     while (button == QDialog::Accepted && !goodName && name.isNull()) {
-        QPointer<UMLAttributeDialog> attributeDialog = new UMLAttributeDialog(0, newAttribute);
+        QPointer<UMLAttributeDialog> attributeDialog = new UMLAttributeDialog(nullptr, newAttribute);
         button = attributeDialog->exec();
         QString name = newAttribute->name();
 
         if(name.length() == 0) {
-            KMessageBox::error(0, i18n("That is an invalid name."), i18n("Invalid Name"));
-        } else if (findChildObject(name) != 0) {
-            KMessageBox::error(0, i18n("That name is already being used."), i18n("Not a Unique Name"));
+            KMessageBox::error(nullptr, i18n("That is an invalid name."), i18n("Invalid Name"));
+        } else if (findChildObject(name) != nullptr) {
+            KMessageBox::error(nullptr, i18n("That name is already being used."), i18n("Not a Unique Name"));
         } else {
             goodName = true;
         }
@@ -789,7 +789,7 @@ UMLAttribute* UMLClassifier::createAttribute(const QString &name,
 
     if (button != QDialog::Accepted) {
         delete newAttribute;
-        return 0;
+        return nullptr;
     }
 
     addAttribute(newAttribute);
@@ -809,7 +809,7 @@ UMLAttribute* UMLClassifier::createAttribute(const QString &name,
 
 UMLAttribute* UMLClassifier::addAttribute(const QString &name, Uml::ID::Type id /* = Uml::id_None */)
 {
-    foreach (UMLObject* obj, subordinates()) {
+    for(UMLObject* obj : subordinates()) {
         uIgnoreZeroPointer(obj);
         if (obj->baseType() == UMLObject::ot_Attribute && obj->name() == name)
             return obj->asUMLAttribute();
@@ -817,7 +817,7 @@ UMLAttribute* UMLClassifier::addAttribute(const QString &name, Uml::ID::Type id
     Uml::Visibility::Enum scope = Settings::optionState().classState.defaultAttributeScope;
     UMLAttribute *a = new UMLAttribute(this, name, id, scope);
     subordinates().append(a);
-    emit attributeAdded(a);
+    Q_EMIT attributeAdded(a);
     UMLObject::emitModified();
     connect(a, SIGNAL(modified()), this, SIGNAL(modified()));
     return a;
@@ -842,7 +842,7 @@ UMLAttribute* UMLClassifier::addAttribute(const QString &name, UMLObject *type,
         a->setType(type);
     }
     subordinates().append(a);
-    emit attributeAdded(a);
+    Q_EMIT attributeAdded(a);
     UMLObject::emitModified();
     connect(a, SIGNAL(modified()), this, SIGNAL(modified()));
     return a;
@@ -860,11 +860,11 @@ UMLAttribute* UMLClassifier::addAttribute(const QString &name, UMLObject *type,
  *                   to the end of the list.
  * @return           True if the attribute was successfully added.
  */
-bool UMLClassifier::addAttribute(UMLAttribute* att, IDChangeLog* log /* = 0 */,
+bool UMLClassifier::addAttribute(UMLAttribute *att, IDChangeLog* log /* = nullptr */,
                                  int position /* = -1 */)
 {
     Q_ASSERT(att);
-    if (findChildObject(att->name()) == 0) {
+    if (findChildObject(att->name()) == nullptr) {
         att->setParent(this);
         if (position >= 0 && position < (int)subordinates().count()) {
             subordinates().insert(position, att);
@@ -872,7 +872,7 @@ bool UMLClassifier::addAttribute(UMLAttribute* att, IDChangeLog* log /* = 0 */,
         else {
             subordinates().append(att);
         }
-        emit attributeAdded(att);
+        Q_EMIT attributeAdded(att);
         UMLObject::emitModified();
         connect(att, SIGNAL(modified()), this, SIGNAL(modified()));
         return true;
@@ -898,7 +898,7 @@ int UMLClassifier::removeAttribute(UMLAttribute* att)
     }
     // note that we don't delete the attribute, just remove it from the Classifier
     disconnect(att, SIGNAL(modified()), this, SIGNAL(modified()));
-    emit attributeRemoved(att);
+    Q_EMIT attributeRemoved(att);
     UMLObject::emitModified();
     return subordinates().count();
 }
@@ -909,7 +909,7 @@ int UMLClassifier::removeAttribute(UMLAttribute* att)
 bool UMLClassifier::hasAbstractOps () const
 {
     UMLOperationList opl(getOpList());
-    foreach(UMLOperation *op, opl) {
+    for(UMLOperation  *op : opl) {
         uIgnoreZeroPointer(op);
         if (op->isAbstract()) {
             return true;
@@ -939,7 +939,7 @@ int UMLClassifier::operations() const
 UMLOperationList UMLClassifier::getOpList(bool includeInherited, UMLClassifierSet *alreadyTraversed) const
 {
     UMLOperationList ops;
-    foreach (UMLObject* li, subordinates()) {
+    for(UMLObject *li : subordinates()) {
         uIgnoreZeroPointer(li);
         if (li->baseType() == ot_Operation) {
             ops.append(li->asUMLOperation());
@@ -957,7 +957,7 @@ UMLOperationList UMLClassifier::getOpList(bool includeInherited, UMLClassifierSe
 
         // get a list of parents of this class
         UMLClassifierList parents = findSuperClassConcepts();
-        foreach(UMLClassifier *c, parents) {
+        for(UMLClassifier  *c : parents) {
             if (alreadyTraversed->contains(c)) {
                 logError2("UMLClassifier::getOpList(%1) : class %2 is starting a dependency loop!",
                           name(), c->name());
@@ -966,10 +966,10 @@ UMLOperationList UMLClassifier::getOpList(bool includeInherited, UMLClassifierSe
             // get operations for each parent by recursive call
             UMLOperationList pops = c->getOpList(true, alreadyTraversed);
             // add these operations to operation list, but only if unique.
-            foreach (UMLOperation *po, pops) {
+            for(UMLOperation  *po : pops) {
                 QString po_as_string(po->toString(Uml::SignatureType::SigNoVis));
                 bool breakFlag = false;
-                foreach (UMLOperation* o,  ops) {
+                for(UMLOperation *o :  ops) {
                     if (o->toString(Uml::SignatureType::SigNoVis) == po_as_string) {
                         breakFlag = true;
                         break;
@@ -983,7 +983,7 @@ UMLOperationList UMLClassifier::getOpList(bool includeInherited, UMLClassifierSe
         }
         if (alreadyTraversed->level-- == 0) {
             delete alreadyTraversed;
-            alreadyTraversed = 0;
+            alreadyTraversed = nullptr;
         }
     }
     return ops;
@@ -999,7 +999,7 @@ UMLOperationList UMLClassifier::getOpList(bool includeInherited, UMLClassifierSe
 UMLClassifierListItemList UMLClassifier::getFilteredList(UMLObject::ObjectType ot) const
 {
     UMLClassifierListItemList resultList;
-    foreach (UMLObject* o, subordinates()) {
+    for(UMLObject *o : subordinates()) {
         uIgnoreZeroPointer(o);
         if (!o || o->baseType() == UMLObject::ot_Association) {
             continue;
@@ -1030,7 +1030,7 @@ UMLTemplate* UMLClassifier::addTemplate(const QString &name, Uml::ID::Type id)
     }
     templt = new UMLTemplate(this, name, id);
     subordinates().append(templt);
-    emit templateAdded(templt);
+    Q_EMIT templateAdded(templt);
     UMLObject::emitModified();
     connect(templt, SIGNAL(modified()), this, SIGNAL(modified()));
     return templt;
@@ -1044,13 +1044,13 @@ UMLTemplate* UMLClassifier::addTemplate(const QString &name, Uml::ID::Type id)
  * @param log           Pointer to the IDChangeLog.
  * @return              True if the template was successfully added.
  */
-bool UMLClassifier::addTemplate(UMLTemplate* newTemplate, IDChangeLog* log /* = 0*/)
+bool UMLClassifier::addTemplate(UMLTemplate* newTemplate, IDChangeLog* log /* = nullptr*/)
 {
     QString name = newTemplate->name();
-    if (findChildObject(name) == 0) {
+    if (findChildObject(name) == nullptr) {
         newTemplate->setParent(this);
         subordinates().append(newTemplate);
-        emit templateAdded(newTemplate);
+        Q_EMIT templateAdded(newTemplate);
         UMLObject::emitModified();
         connect(newTemplate, SIGNAL(modified()), this, SIGNAL(modified()));
         return true;
@@ -1076,7 +1076,7 @@ bool UMLClassifier::addTemplate(UMLTemplate* templt, int position)
 {
     Q_ASSERT(templt);
     QString name = templt->name();
-    if (findChildObject(name) == 0) {
+    if (findChildObject(name) == nullptr) {
         templt->setParent(this);
         if (position >= 0 && position <= (int)subordinates().count()) {
             subordinates().insert(position, templt);
@@ -1084,7 +1084,7 @@ bool UMLClassifier::addTemplate(UMLTemplate* templt, int position)
         else {
             subordinates().append(templt);
         }
-        emit templateAdded(templt);
+        Q_EMIT templateAdded(templt);
         UMLObject::emitModified();
         connect(templt, SIGNAL(modified()), this, SIGNAL(modified()));
         return true;
@@ -1106,7 +1106,7 @@ int UMLClassifier::removeTemplate(UMLTemplate* umltemplate)
         logWarn1("UMLClassifier::removeTemplate(%1) : cannot find att given in list", name());
         return -1;
     }
-    emit templateRemoved(umltemplate);
+    Q_EMIT templateRemoved(umltemplate);
     UMLObject::emitModified();
     disconnect(umltemplate, SIGNAL(modified()), this, SIGNAL(modified()));
     return subordinates().count();
@@ -1120,12 +1120,12 @@ int UMLClassifier::removeTemplate(UMLTemplate* umltemplate)
 UMLTemplate *UMLClassifier::findTemplate(const QString& name) const
 {
     UMLTemplateList templParams = getTemplateList();
-    foreach (UMLTemplate *templt, templParams) {
+    for(UMLTemplate  *templt : templParams) {
         if (templt->name() == name) {
             return templt;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 /**
@@ -1149,7 +1149,7 @@ int UMLClassifier::templates() const
 UMLTemplateList UMLClassifier::getTemplateList() const
 {
     UMLTemplateList templateList;
-    foreach (UMLObject* listItem, subordinates()) {
+    for(UMLObject *listItem : subordinates()) {
         uIgnoreZeroPointer(listItem);
         if (listItem->baseType() == UMLObject::ot_Template) {
             templateList.append(listItem->asUMLTemplate());
@@ -1169,7 +1169,7 @@ UMLTemplateList UMLClassifier::getTemplateList() const
 int UMLClassifier::takeItem(UMLClassifierListItem *item)
 {
     QString buf;
-    foreach (UMLObject* currentAtt, subordinates()) {
+    for(UMLObject *currentAtt : subordinates()) {
         uIgnoreZeroPointer(currentAtt);
 #if 0
         QString txt = currentAtt->name();
@@ -1195,7 +1195,7 @@ int UMLClassifier::takeItem(UMLClassifierListItem *item)
         case UMLObject::ot_Attribute: {
             UMLAttribute *retval = subordinates().takeAt(index)->asUMLAttribute();
             if (retval) {
-                emit attributeRemoved(retval);
+                Q_EMIT attributeRemoved(retval);
                 UMLObject::emitModified();
             } else {
                 index = -1;
@@ -1205,7 +1205,7 @@ int UMLClassifier::takeItem(UMLClassifierListItem *item)
         case UMLObject::ot_Template: {
             UMLTemplate *templt = subordinates().takeAt(index)->asUMLTemplate();
             if (templt) {
-                emit templateRemoved(templt);
+                Q_EMIT templateRemoved(templt);
                 UMLObject::emitModified();
             } else {
                 index = -1;
@@ -1320,7 +1320,7 @@ UMLAssociationList  UMLClassifier::getUniAssociationToBeImplemented() const
     UMLAssociationList associations = getSpecificAssocs(AssociationType::UniAssociation);
     UMLAssociationList uniAssocListToBeImplemented;
 
-    foreach (UMLAssociation *a, associations) {
+    for(UMLAssociation *a : associations) {
         uIgnoreZeroPointer(a);
         if (a->getObjectId(RoleType::B) == id()) {
             continue;  // we need to be at the A side
@@ -1330,7 +1330,7 @@ UMLAssociationList  UMLClassifier::getUniAssociationToBeImplemented() const
             UMLAttributeList atl = getAttributeList();
             bool found = false;
             //make sure that an attribute with the same name doesn't already exist
-            foreach (UMLAttribute *at, atl) {
+            for(UMLAttribute *at : atl) {
                 uIgnoreZeroPointer(at);
                 if (at->name() == roleNameB) {
                     found = true;
@@ -1378,7 +1378,7 @@ void UMLClassifier::saveToXMI(QXmlStreamWriter& writer)
         if (! Settings::optionState().generalState.uml2) {
             writer.writeStartElement(QStringLiteral("UML:ModelElement.templateParameter"));
         }
-        foreach (UMLClassifierListItem *tmpl, list) {
+        for(UMLClassifierListItem *tmpl : list) {
             tmpl->saveToXMI(writer);
         }
         if (! Settings::optionState().generalState.uml2) {
@@ -1392,7 +1392,7 @@ void UMLClassifier::saveToXMI(QXmlStreamWriter& writer)
         if (! Settings::optionState().generalState.uml2) {
             writer.writeStartElement(QStringLiteral("UML:GeneralizableElement.generalization"));
         }
-        foreach (UMLAssociation *asso, generalizations) {
+        for(UMLAssociation *asso : generalizations) {
             // We are the subclass if we are at the role A end.
             if (m_nId != asso->getObjectId(RoleType::A)) {
                 continue;
@@ -1423,11 +1423,11 @@ void UMLClassifier::saveToXMI(QXmlStreamWriter& writer)
             writer.writeStartElement(QStringLiteral("UML:Classifier.feature"));
         }
         // save attributes
-        foreach (UMLClassifierListItem *pAtt, attList) {
+        for(UMLClassifierListItem *pAtt : attList) {
             pAtt->saveToXMI(writer);
         }
         // save operations
-        foreach (UMLOperation *pOp, opList) {
+        for(UMLOperation *pOp : opList) {
             pOp->saveToXMI(writer);
         }
         if (! Settings::optionState().generalState.uml2) {
@@ -1440,7 +1440,7 @@ void UMLClassifier::saveToXMI(QXmlStreamWriter& writer)
         if (! Settings::optionState().generalState.uml2) {
             writer.writeStartElement(QStringLiteral("UML:Namespace.ownedElement"));
         }
-        foreach (UMLObject* obj, m_objects) {
+        for(UMLObject* obj : m_objects) {
             uIgnoreZeroPointer(obj);
             obj->saveToXMI (writer);
         }
@@ -1460,14 +1460,14 @@ void UMLClassifier::saveToXMI(QXmlStreamWriter& writer)
  */
 UMLClassifierListItem* UMLClassifier::makeChildObject(const QString& xmiTag)
 {
-    UMLClassifierListItem* pObject = 0;
+    UMLClassifierListItem *pObject = nullptr;
     if (UMLDoc::tagEq(xmiTag, QStringLiteral("Operation")) ||
         UMLDoc::tagEq(xmiTag, QStringLiteral("ownedOperation"))) {
         pObject = new UMLOperation(this);
     } else if (UMLDoc::tagEq(xmiTag, QStringLiteral("Attribute")) ||
                UMLDoc::tagEq(xmiTag, QStringLiteral("ownedAttribute"))) {
         if (baseType() != UMLObject::ot_Class)
-            return 0;
+            return nullptr;
         pObject = new UMLAttribute(this);
     } else if (UMLDoc::tagEq(xmiTag, QStringLiteral("TemplateParameter")) ||
                UMLDoc::tagEq(xmiTag, QStringLiteral("ClassifierTemplateParameter"))) {
@@ -1512,7 +1512,7 @@ void UMLClassifier::removeObject(UMLObject *pObject)
  */
 bool UMLClassifier::load1(QDomElement& element)
 {
-    UMLClassifierListItem *child = 0;
+    UMLClassifierListItem  *child = nullptr;
     bool totalSuccess = true;
     for (QDomNode node = element.firstChild(); !node.isNull();
             node = node.nextSibling()) {
@@ -1530,7 +1530,7 @@ bool UMLClassifier::load1(QDomElement& element)
             // Not evaluating the return value from load()
             // because we want a best effort.
 
-        } else if ((child = makeChildObject(tag)) != 0) {
+        } else if ((child = makeChildObject(tag)) != nullptr) {
             if (child->loadFromXMI(element)) {
                 switch (child->baseType()) {
                     case UMLObject::ot_Template:
@@ -1557,7 +1557,7 @@ bool UMLClassifier::load1(QDomElement& element)
             }
         } else if (!Model_Utils::isCommonXMI1Attribute(tag)) {
             UMLObject *pObject = Object_Factory::makeObjectFromXMI(tag, stereotype);
-            if (pObject == 0) {
+            if (pObject == nullptr) {
                 // Not setting totalSuccess to false
                 // because we want a best effort.
                 continue;
