@@ -75,7 +75,7 @@ public:
     virtual void removeAllChildObjects();
 
     UMLObjectList &subordinates() const {
-        m_List.removeAll(0);
+        m_List.removeAll(nullptr);
         return m_List;
     }
 
@@ -96,7 +96,7 @@ private:
      */
     mutable UMLObjectList m_List;
 
-signals:
+Q_SIGNALS:
 
     void sigAssociationEndAdded(UMLAssociation * assoc);
     void sigAssociationEndRemoved(UMLAssociation * assoc);
