@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2002-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2002-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #include "usecase.h"
@@ -47,7 +47,7 @@ UMLObject* UMLUseCase::clone() const
  */
 void UMLUseCase::saveToXMI(QXmlStreamWriter& writer)
 {
-    UMLObject::save1(writer, QLatin1String("UseCase"));
+    UMLObject::save1(writer, QStringLiteral("UseCase"));
     UMLObject::save1end(writer);
 }
 
