@@ -227,9 +227,10 @@ void WorkToolBar::buttonChanged(int b)
 
         // signal needed, in the case (when switching diagrams) that
         // Arrow Button gets activated, but the toolBarState of the Views may be different
-        emit sigButtonChanged(m_CurrentButtonID);
+        Q_EMIT sigButtonChanged(m_CurrentButtonID);
 
-        view->setCursor(currentCursor());
+        if (view)
+            view->setCursor(currentCursor());
         return;
     }
 
@@ -238,15 +239,17 @@ void WorkToolBar::buttonChanged(int b)
         m_map[m_Type] = m_CurrentButtonID;  // store old tool for this diagram type
         m_actions[tbb_Arrow]->toggle();
         m_CurrentButtonID = tbb_Arrow;
-        emit sigButtonChanged(m_CurrentButtonID);
-        view->setCursor(currentCursor());
+        Q_EMIT sigButtonChanged(m_CurrentButtonID);
+        if (view)
+            view->setCursor(currentCursor());
         return;
     }
     m_map[m_Type] = m_CurrentButtonID;
     m_actions[m_CurrentButtonID]->toggle();
     m_CurrentButtonID = tbb;
-    emit sigButtonChanged(m_CurrentButtonID);
-    view->setCursor(currentCursor());
+    Q_EMIT sigButtonChanged(m_CurrentButtonID);
+    if (view)
+        view->setCursor(currentCursor());
 }
 
 /**
@@ -274,10 +277,10 @@ void WorkToolBar::slotResetToolBar()
     m_actions[m_CurrentButtonID]->toggle();
     m_CurrentButtonID = tbb_Arrow;
     m_actions[m_CurrentButtonID]->toggle();
-    emit sigButtonChanged(m_CurrentButtonID);
+    Q_EMIT sigButtonChanged(m_CurrentButtonID);
 
     UMLView* view = UMLApp::app()->currentView();
-    if (view != 0) {
+    if (view != nullptr) {
         view->setCursor(defaultCursor());
     }
 }
@@ -484,7 +487,7 @@ void WorkToolBar::slotSubsystem()                { buttonChanged(tbb_SubSystem);
  */
 void WorkToolBar::setupActions()
 {
-    foreach(QAction *action, m_actions) {
+    for(QAction *action : m_actions) {
         if (!action->shortcut().isEmpty()) {
             action->setToolTip(action->text() + QStringLiteral("\t[") +
                                action->shortcut().toString() + QStringLiteral("]"));
